*** dev/cxm/cxm_v4l.h.orig	Tue Jan 11 19:50:16 2005
--- dev/cxm/cxm_v4l.h	Tue Jan 11 19:49:05 2005
***************
*** 0 ****
--- 1,441 ----
+ /*
+  *   	A "V4L2-like" ioctl API for the cxm driver
+  */
+ 
+ #ifndef _MACHINE_IOCTL_CXM_H_
+ #define _MACHINE_IOCTL_CXM_H_
+ 
+ #ifndef _KERNEL
+ #include <sys/types.h>
+ #endif
+ 
+ #define __u8	u_int8_t
+ #define __u32	u_int32_t
+ #define __u64   u_int64_t
+ #define __s32	int32_t
+ 
+ typedef __u64 v4l2_std_id;
+ 
+ 
+ /*   
+  *      D R I V E R   C A P A B I L I T I E S
+  */
+ struct v4l2_capability
+ {
+         __u8    driver[16];     /* i.e. "bttv" */
+         __u8    card[32];       /* i.e. "Hauppauge WinTV" */
+         __u8    bus_info[32];   /* "PCI:" + pci_dev->slot_name */
+         __u32   version;        /* should use KERNEL_VERSION() */
+         __u32   capabilities;   /* Device capabilities */
+         __u32   reserved[4];
+ };
+ 
+ 
+ /* Values for 'capabilities' field */
+ #define V4L2_CAP_VIDEO_CAPTURE  0x00000001  /* Is a video capture device */
+ #define V4L2_CAP_VIDEO_OUTPUT   0x00000002  /* Is a video output device */
+ #define V4L2_CAP_VIDEO_OVERLAY  0x00000004  /* Can do video overlay */
+ #define V4L2_CAP_VBI_CAPTURE    0x00000010  /* Is a VBI capture device */
+ #define V4L2_CAP_VBI_OUTPUT     0x00000020  /* Is a VBI output device */
+ #define V4L2_CAP_RDS_CAPTURE    0x00000100  /* RDS data capture */
+ 
+ #define V4L2_CAP_TUNER          0x00010000  /* Has a tuner */
+ #define V4L2_CAP_AUDIO          0x00020000  /* has audio support */
+ 
+ #define V4L2_CAP_READWRITE      0x01000000  /* read/write systemcalls */
+ #define V4L2_CAP_ASYNCIO        0x02000000  /* async I/O */
+ #define V4L2_CAP_STREAMING      0x04000000  /* streaming I/O ioctls */
+ 
+ /*
+  *      V I D E O   I N P U T S
+  */
+ struct v4l2_input
+ {
+         __u32        index;             /*  Which input */
+         __u8         name[32];          /*  Label */
+         __u32        type;              /*  Type of input */
+         __u32        audioset;          /*  Associated audios (bitfield) */
+         __u32        tuner;             /*  Associated tuner */   
+         v4l2_std_id  std;
+         __u32        status;
+         __u32        reserved[4];
+ };
+ /*  Values for the 'type' field */
+ #define V4L2_INPUT_TYPE_TUNER           1
+ #define V4L2_INPUT_TYPE_CAMERA          2
+ 
+ /* field 'status' - general */
+ #define V4L2_IN_ST_NO_POWER    0x00000001  /* Attached device is off */
+ #define V4L2_IN_ST_NO_SIGNAL   0x00000002
+ #define V4L2_IN_ST_NO_COLOR    0x00000004
+ 
+ /* field 'status' - analog */
+ #define V4L2_IN_ST_NO_H_LOCK   0x00000100  /* No horizontal sync lock */
+ #define V4L2_IN_ST_COLOR_KILL  0x00000200  /* Color killer is active */
+ 
+ /* field 'status' - digital */
+ #define V4L2_IN_ST_NO_SYNC     0x00010000  /* No synchronization lock */
+ #define V4L2_IN_ST_NO_EQU      0x00020000  /* No equalizer lock */
+ #define V4L2_IN_ST_NO_CARRIER  0x00040000  /* Carrier recovery failed */
+ 
+ /* field 'status' - VCR and set-top box */
+ #define V4L2_IN_ST_MACROVISION 0x01000000  /* Macrovision detected */
+ #define V4L2_IN_ST_NO_ACCESS   0x02000000  /* Conditional access denied */
+ #define V4L2_IN_ST_VTR         0x04000000  /* VTR time constant */
+ 
+ 
+ /*
+  *      T U N I N G
+  */
+ enum v4l2_tuner_type {
+         V4L2_TUNER_RADIO             = 1,
+         V4L2_TUNER_ANALOG_TV         = 2,
+ };
+ 
+ struct v4l2_tuner
+ {
+         __u32                   index;   
+         __u8                    name[32]; 
+         enum v4l2_tuner_type    type;
+         __u32                   capability;
+         __u32                   rangelow;
+         __u32                   rangehigh;
+         __u32                   rxsubchans;
+         __u32                   audmode;
+         __s32                   signal;
+         __s32                   afc;
+         __u32                   reserved[4];
+ };
+ 
+ struct v4l2_frequency
+ {
+         __u32                 tuner;
+         enum v4l2_tuner_type  type;
+         __u32                 frequency;
+         __u32                 reserved[8];
+ };
+ 
+ 
+ /*
+  *      A N A L O G   V I D E O   S T A N D A R D   
+  */
+ 
+ 
+ /* one bit for each */
+ #define V4L2_STD_PAL_B          ((v4l2_std_id)0x00000001)
+ #define V4L2_STD_PAL_B1         ((v4l2_std_id)0x00000002)
+ #define V4L2_STD_PAL_G          ((v4l2_std_id)0x00000004)
+ #define V4L2_STD_PAL_H          ((v4l2_std_id)0x00000008)
+ #define V4L2_STD_PAL_I          ((v4l2_std_id)0x00000010)
+ #define V4L2_STD_PAL_D          ((v4l2_std_id)0x00000020)
+ #define V4L2_STD_PAL_D1         ((v4l2_std_id)0x00000040)
+ #define V4L2_STD_PAL_K          ((v4l2_std_id)0x00000080)
+ 
+ #define V4L2_STD_PAL_M          ((v4l2_std_id)0x00000100)
+ #define V4L2_STD_PAL_N          ((v4l2_std_id)0x00000200)
+ #define V4L2_STD_PAL_Nc         ((v4l2_std_id)0x00000400)
+ #define V4L2_STD_PAL_60         ((v4l2_std_id)0x00000800)
+ 
+ #define V4L2_STD_NTSC_M         ((v4l2_std_id)0x00001000)
+ #define V4L2_STD_NTSC_M_JP      ((v4l2_std_id)0x00002000)
+ 
+ #define V4L2_STD_SECAM_B        ((v4l2_std_id)0x00010000)
+ #define V4L2_STD_SECAM_D        ((v4l2_std_id)0x00020000)
+ #define V4L2_STD_SECAM_G        ((v4l2_std_id)0x00040000)
+ #define V4L2_STD_SECAM_H        ((v4l2_std_id)0x00080000)
+ #define V4L2_STD_SECAM_K        ((v4l2_std_id)0x00100000)
+ #define V4L2_STD_SECAM_K1       ((v4l2_std_id)0x00200000)
+ #define V4L2_STD_SECAM_L        ((v4l2_std_id)0x00400000)
+ 
+ /* ATSC/HDTV */
+ #define V4L2_STD_ATSC_8_VSB     ((v4l2_std_id)0x01000000)
+ #define V4L2_STD_ATSC_16_VSB    ((v4l2_std_id)0x02000000)
+ 
+ /* some common needed stuff */
+ #define V4L2_STD_PAL_BG         (V4L2_STD_PAL_B         |\
+                                  V4L2_STD_PAL_B1        |\
+                                  V4L2_STD_PAL_G)
+ #define V4L2_STD_PAL_DK         (V4L2_STD_PAL_D         |\
+                                  V4L2_STD_PAL_D1        |\
+                                  V4L2_STD_PAL_K)
+ #define V4L2_STD_PAL            (V4L2_STD_PAL_BG        |\
+                                  V4L2_STD_PAL_DK        |\
+                                  V4L2_STD_PAL_H         |\
+                                  V4L2_STD_PAL_I)
+ #define V4L2_STD_NTSC           (V4L2_STD_NTSC_M        |\
+                                  V4L2_STD_NTSC_M_JP)
+ #define V4L2_STD_SECAM          (V4L2_STD_SECAM_B       |\
+                                  V4L2_STD_SECAM_D       |\
+                                  V4L2_STD_SECAM_G       |\
+                                  V4L2_STD_SECAM_H       |\
+                                  V4L2_STD_SECAM_K       |\
+                                  V4L2_STD_SECAM_K1      |\
+                                  V4L2_STD_SECAM_L)
+ 
+ #define V4L2_STD_525_60         (V4L2_STD_PAL_M         |\
+                                  V4L2_STD_PAL_60        |\
+                                  V4L2_STD_NTSC)
+ #define V4L2_STD_625_50         (V4L2_STD_PAL           |\
+                                  V4L2_STD_PAL_N         |\
+                                  V4L2_STD_PAL_Nc        |\
+                                  V4L2_STD_SECAM)
+ 
+ #define V4L2_STD_UNKNOWN        0
+ #define V4L2_STD_ALL            (V4L2_STD_525_60        |\
+                                  V4L2_STD_625_50)
+ /*
+  *      C O N T R O L S
+  */
+ struct v4l2_control
+ {
+         __u32                id;
+         __s32                value;
+ };
+ 
+ enum v4l2_ctrl_type {
+         V4L2_CTRL_TYPE_INTEGER       = 1,
+         V4L2_CTRL_TYPE_BOOLEAN       = 2,
+         V4L2_CTRL_TYPE_MENU          = 3,
+         V4L2_CTRL_TYPE_BUTTON        = 4,
+ };
+ 
+ /*  Used in the VIDIOC_QUERYCTRL ioctl for querying controls */   
+ struct v4l2_queryctrl
+ {
+         __u32                id;
+         enum v4l2_ctrl_type  type;
+         __u8                 name[32];  /* Whatever */
+         __s32                minimum;   /* Note signedness */
+         __s32                maximum;
+         __s32                step;
+         __s32                default_value;
+         __u32                flags;
+         __u32                reserved[2];
+ };
+ 
+ /*  Control flags  */
+ #define V4L2_CTRL_FLAG_DISABLED         0x0001
+ #define V4L2_CTRL_FLAG_GRABBED          0x0002
+ 
+ /*  Control IDs defined by V4L2 */
+ #define V4L2_CID_BASE                   0x00980900
+ /*  IDs reserved for driver specific controls */
+ #define V4L2_CID_PRIVATE_BASE           0x08000000
+ 
+ #define V4L2_CID_BRIGHTNESS             (V4L2_CID_BASE+0)
+ #define V4L2_CID_CONTRAST               (V4L2_CID_BASE+1)
+ #define V4L2_CID_SATURATION             (V4L2_CID_BASE+2)
+ #define V4L2_CID_HUE                    (V4L2_CID_BASE+3)
+ #define V4L2_CID_AUDIO_VOLUME           (V4L2_CID_BASE+5)
+ #define V4L2_CID_AUDIO_BALANCE          (V4L2_CID_BASE+6)
+ #define V4L2_CID_AUDIO_BASS             (V4L2_CID_BASE+7)
+ #define V4L2_CID_AUDIO_TREBLE           (V4L2_CID_BASE+8)
+ #define V4L2_CID_AUDIO_MUTE             (V4L2_CID_BASE+9)
+ #define V4L2_CID_AUDIO_LOUDNESS         (V4L2_CID_BASE+10)
+ #define V4L2_CID_BLACK_LEVEL            (V4L2_CID_BASE+11)
+ #define V4L2_CID_AUTO_WHITE_BALANCE     (V4L2_CID_BASE+12)
+ #define V4L2_CID_DO_WHITE_BALANCE       (V4L2_CID_BASE+13)
+ #define V4L2_CID_RED_BALANCE            (V4L2_CID_BASE+14)
+ #define V4L2_CID_BLUE_BALANCE           (V4L2_CID_BASE+15)
+ #define V4L2_CID_GAMMA                  (V4L2_CID_BASE+16)
+ #define V4L2_CID_WHITENESS              (V4L2_CID_GAMMA) /* ? Not sure */
+ #define V4L2_CID_EXPOSURE               (V4L2_CID_BASE+17)
+ #define V4L2_CID_AUTOGAIN               (V4L2_CID_BASE+18)
+ #define V4L2_CID_GAIN                   (V4L2_CID_BASE+19)
+ #define V4L2_CID_HFLIP                  (V4L2_CID_BASE+20)
+ #define V4L2_CID_VFLIP                  (V4L2_CID_BASE+21)
+ #define V4L2_CID_HCENTER                (V4L2_CID_BASE+22)
+ #define V4L2_CID_VCENTER                (V4L2_CID_BASE+23)
+ #define V4L2_CID_LASTP1                 (V4L2_CID_BASE+24) /* last CID + 1 */
+ 
+ 
+ /*
+  *      V I D E O   I M A G E   F O R M A T
+  */
+         
+ enum v4l2_field {
+         V4L2_FIELD_ANY        = 0, /* driver can choose from none,
+                                       top, bottom, interlaced
+                                       depending on whatever it thinks
+                                       is approximate ... */
+         V4L2_FIELD_NONE       = 1, /* this device has no fields ... */
+         V4L2_FIELD_TOP        = 2, /* top field only */
+         V4L2_FIELD_BOTTOM     = 3, /* bottom field only */
+         V4L2_FIELD_INTERLACED = 4, /* both fields interlaced */
+         V4L2_FIELD_SEQ_TB     = 5, /* both fields sequential into one
+                                       buffer, top-bottom order */
+         V4L2_FIELD_SEQ_BT     = 6, /* same as above + bottom-top order */
+         V4L2_FIELD_ALTERNATE  = 7, /* both fields alternating into
+                                       separate buffers */
+ };
+ 
+ enum v4l2_colorspace {
+         /* ITU-R 601 -- broadcast NTSC/PAL */
+         V4L2_COLORSPACE_SMPTE170M     = 1,
+         
+         /* 1125-Line (US) HDTV */
+         V4L2_COLORSPACE_SMPTE240M     = 2,
+         
+         /* HD and modern captures. */
+         V4L2_COLORSPACE_REC709        = 3,
+        
+         /* broken BT878 extents (601, luma range 16-253 instead of 16-235) */
+         V4L2_COLORSPACE_BT878         = 4,   
+        
+         /* These should be useful.  Assume 601 extents. */
+         V4L2_COLORSPACE_470_SYSTEM_M  = 5,
+         V4L2_COLORSPACE_470_SYSTEM_BG = 6,
+        
+         /* I know there will be cameras that send this.  So, this is
+          * unspecified chromaticities and full 0-255 on each of the
+          * Y'CbCr components
+          */
+         V4L2_COLORSPACE_JPEG          = 7,
+        
+         /* For RGB colourspaces, this is probably a good start. */
+         V4L2_COLORSPACE_SRGB          = 8,
+ };
+ 
+ enum v4l2_buf_type {
+         V4L2_BUF_TYPE_VIDEO_CAPTURE  = 1,
+         V4L2_BUF_TYPE_VIDEO_OUTPUT   = 2,
+         V4L2_BUF_TYPE_VIDEO_OVERLAY  = 3,
+         V4L2_BUF_TYPE_VBI_CAPTURE    = 4,
+         V4L2_BUF_TYPE_VBI_OUTPUT     = 5,
+         V4L2_BUF_TYPE_PRIVATE        = 0x80,
+ };
+ 
+ struct v4l2_pix_format
+ {
+         __u32                   width;   
+         __u32                   height;  
+         __u32                   pixelformat;
+         enum v4l2_field         field;   
+         __u32                   bytesperline;   /* for padding, zero if unused */ 
+         __u32                   sizeimage;
+         enum v4l2_colorspace    colorspace;
+         __u32                   priv;           /* private data, depends on pixelformat */
+ };
+ 
+ /*           Pixel format    FOURCC                  depth  Description   */
+ #define V4L2_PIX_FMT_RGB332  v4l2_fourcc('R','G','B','1') /*  8  RGB-3-3-2     */
+ #define V4L2_PIX_FMT_RGB555  v4l2_fourcc('R','G','B','O') /* 16  RGB-5-5-5     */
+ #define V4L2_PIX_FMT_RGB565  v4l2_fourcc('R','G','B','P') /* 16  RGB-5-6-5     */
+ #define V4L2_PIX_FMT_RGB555X v4l2_fourcc('R','G','B','Q') /* 16  RGB-5-5-5 BE  */
+ #define V4L2_PIX_FMT_RGB565X v4l2_fourcc('R','G','B','R') /* 16  RGB-5-6-5 BE  */
+ #define V4L2_PIX_FMT_BGR24   v4l2_fourcc('B','G','R','3') /* 24  BGR-8-8-8     */
+ #define V4L2_PIX_FMT_RGB24   v4l2_fourcc('R','G','B','3') /* 24  RGB-8-8-8     */
+ #define V4L2_PIX_FMT_BGR32   v4l2_fourcc('B','G','R','4') /* 32  BGR-8-8-8-8   */
+ #define V4L2_PIX_FMT_RGB32   v4l2_fourcc('R','G','B','4') /* 32  RGB-8-8-8-8   */
+ 
+ /* two planes -- one Y, one Cr + Cb interleaved  */
+ #define V4L2_PIX_FMT_NV12    v4l2_fourcc('N','V','1','2') /* 12  Y/CbCr 4:2:0  */
+ #define V4L2_PIX_FMT_NV21    v4l2_fourcc('N','V','2','1') /* 12  Y/CrCb 4:2:0  */
+ 
+ /*  The following formats are not defined in the V4L2 specification */
+ #define V4L2_PIX_FMT_YUV410  v4l2_fourcc('Y','U','V','9') /*  9  YUV 4:1:0     */
+ #define V4L2_PIX_FMT_YUV420  v4l2_fourcc('Y','U','1','2') /* 12  YUV 4:2:0     */
+ #define V4L2_PIX_FMT_YYUV    v4l2_fourcc('Y','Y','U','V') /* 16  YUV 4:2:2     */
+ #define V4L2_PIX_FMT_HI240   v4l2_fourcc('H','I','2','4') /*  8  8-bit color   */
+ 
+ /* compressed formats */
+ #define V4L2_PIX_FMT_MJPEG    v4l2_fourcc('M','J','P','G') /* Motion-JPEG   */
+ #define V4L2_PIX_FMT_JPEG     v4l2_fourcc('J','P','E','G') /* JFIF JPEG     */
+ #define V4L2_PIX_FMT_DV       v4l2_fourcc('d','v','s','d') /* 1394          */
+ #define V4L2_PIX_FMT_MPEG     v4l2_fourcc('M','P','E','G') /* MPEG          */
+ 
+ /*  Vendor-specific formats   */
+ #define V4L2_PIX_FMT_WNVA    v4l2_fourcc('W','N','V','A') /* Winnov hw compres */
+ 
+ struct v4l2_rect {
+         __s32   left;
+         __s32   top;
+         __s32   width;
+         __s32   height;
+ };
+ 
+ struct v4l2_clip
+ {
+         struct v4l2_rect        c;
+         struct v4l2_clip        *next;
+ };     
+         
+ struct v4l2_window
+ {
+         struct v4l2_rect        w;
+         enum v4l2_field         field;
+         __u32                   chromakey;
+         struct v4l2_clip        *clips;
+         __u32                   clipcount;
+         void                    *bitmap;
+ };
+ 
+ struct v4l2_vbi_format
+ {
+         __u32   sampling_rate;          /* in 1 Hz */
+         __u32   offset;
+         __u32   samples_per_line;
+         __u32   sample_format;          /* V4L2_PIX_FMT_* */
+         __s32   start[2];
+         __u32   count[2];
+         __u32   flags;                  /* V4L2_VBI_* */
+         __u32   reserved[2];            /* must be zero */
+ };      
+ 
+ /*  VBI flags  */
+ #define V4L2_VBI_UNSYNC         (1<< 0)
+ #define V4L2_VBI_INTERLACED     (1<< 1)
+  
+ /*      Stream data format
+  */
+ struct v4l2_format
+ {
+         enum v4l2_buf_type type;
+         union
+         {
+                 struct v4l2_pix_format  pix;  /* V4L2_BUF_TYPE_VIDEO_CAPTURE */
+                 struct v4l2_window      win;  /* V4L2_BUF_TYPE_VIDEO_OVERLAY */
+                 struct v4l2_vbi_format  vbi;  /* V4L2_BUF_TYPE_VBI_CAPTURE */
+                 __u8    raw_data[200];        /* user-defined */
+         } fmt;
+ };
+ 
+ /* For use with IVTV_IOC_G_CODEC and IVTV_IOC_S_CODEC */
+ struct ivtv_ioctl_codec {
+         uint32_t aspect;
+         uint32_t audio_bitmask;  
+         uint32_t bframes;
+         uint32_t bitrate_mode;
+         uint32_t bitrate;
+         uint32_t bitrate_peak;
+         uint32_t dnr_mode;
+         uint32_t dnr_spatial;
+         uint32_t dnr_temporal;
+         uint32_t dnr_type;
+         uint32_t framerate;
+         uint32_t framespergop;
+         uint32_t gop_closure;
+         uint32_t pulldown;
+         uint32_t stream_type;
+ };
+ 
+ 
+ 
+ /*
+  *      I O C T L   C O D E S   F O R   V I D E O   D E V I C E S
+  *
+  */
+ #define VIDIOC_QUERYCAP         _IOR  ('V',  0, struct v4l2_capability)
+ #define VIDIOC_G_FMT            _IOWR ('V',  4, struct v4l2_format)
+ #define VIDIOC_S_FMT            _IOWR ('V',  5, struct v4l2_format)
+ #define VIDIOC_S_STD            _IOW  ('V', 24, v4l2_std_id)
+ #define VIDIOC_ENUMINPUT        _IOWR ('V', 26, struct v4l2_input)
+ #define VIDIOC_S_CTRL           _IOW  ('V', 28, struct v4l2_control)
+ #define VIDIOC_G_TUNER          _IOWR ('V', 29, struct v4l2_tuner)
+ #define VIDIOC_QUERYCTRL        _IOWR ('V', 36, struct v4l2_queryctrl)
+ #define VIDIOC_S_INPUT          _IOWR ('V', 39, int)
+ #define VIDIOC_S_FREQUENCY      _IOW  ('V', 57, struct v4l2_frequency)
+ #define IVTV_IOC_G_CODEC	_IOR  ('V', 73, struct ivtv_ioctl_codec)
+ #define IVTV_IOC_S_CODEC	_IOWR ('V', 74, struct ivtv_ioctl_codec)
+ 
+ #endif /* ! _MACHINE_IOCTL_CXM_H_ */
